//
//  SignMessageModalViewController.swift
//  KlipSDK-Sample
//
//  Created by Won on 2022/08/18.
//  Copyright © 2022 GroundX Corp. All rights reserved.
//

import UIKit
import KlipLib

class SignMessageModalViewController: UIViewController, UITextFieldDelegate, UITextViewDelegate {
    var errorData: ResponseErrorModel?
    var delegate : SendReqeustKeyDelegaete?
    var keyboardShown:Bool = false
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "SignMessageError" {
            let errorModalViewController = segue.destination as! ErrorModalViewController
            errorModalViewController.errorData = self.errorData
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        NotificationCenter.default.addObserver(self, selector: #selector(keyboardWillShow(_:)), name: UIResponder.keyboardWillShowNotification, object: nil)
        NotificationCenter.default.addObserver(self, selector: #selector(keyboardWillHide(_:)), name: UIResponder.keyboardWillHideNotification, object: nil)
    }
    
    @objc func keyboardWillShow(_ sender: Notification) {
        if let keyboardFrame: NSValue = sender.userInfo?[UIResponder.keyboardFrameEndUserInfoKey] as? NSValue {
            let keyboardRectangle = keyboardFrame.cgRectValue
            let keyboardHeight = keyboardRectangle.height
            
            if keyboardHeight == 0.0 || keyboardShown == true || self.value.isTracking {
                return
            }
            
            self.view.frame.origin.y -= keyboardHeight
            keyboardShown = true
        }
    }
    
    @objc func keyboardWillHide(_ sender: Notification) {
        if keyboardShown == false {
            return
        }
        
        if let keyboardFrame: NSValue = sender.userInfo?[UIResponder.keyboardFrameEndUserInfoKey] as? NSValue {
            let keyboardRectangle = keyboardFrame.cgRectValue
            let keyboardHeight = keyboardRectangle.height
            
            self.view.frame.origin.y += keyboardHeight
            keyboardShown = false
        }
    }
    
    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?){
        self.view.endEditing(true)
    }
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        textField.resignFirstResponder()
        return true
    }
    
    @IBAction func hideSignMessageModal(_ sender: Any) {
        self.dismiss(animated: true)
    }
    @IBOutlet weak var value: UITextField! {didSet {value.delegate = self}}
    @IBOutlet weak var fromAddress: UITextField! {didSet {fromAddress.delegate = self}}
    @IBOutlet weak var bappName: UITextField! {didSet {bappName.delegate = self}}
    @IBOutlet weak var successCallbackURL: UITextField! {didSet {successCallbackURL.delegate = self}}
    @IBOutlet weak var failCallbackURL: UITextField! {didSet {failCallbackURL.delegate = self}}
    @IBAction func prepareSignMessage(_ sender: Any) {
        if (bappName.text?.isEmpty == false && value.text?.isEmpty == false) {
            let signMessageRequest = SignMessageRequest(value: value.text!, from: fromAddress.text!)
            let bappCallbackLink: BAppDeepLinkCB?
            if(successCallbackURL.text?.isEmpty == false || failCallbackURL.text?.isEmpty == false) {
                bappCallbackLink = BAppDeepLinkCB(successURL: successCallbackURL.text!, failURL: failCallbackURL.text!)
            } else {
                bappCallbackLink = nil
            }
            let bappInfo: BAppInfo = BAppInfo(name : bappName.text!, callback: bappCallbackLink)
            KlipSDK.shared.prepare(request: signMessageRequest, bappInfo: bappInfo) { result in
                switch result {
                case .success(let response):
                    print(response)
                    DispatchQueue.main.async {
                        self.delegate?.dataReceived(data: response.requestKey)
                    }
                    
                    DispatchQueue.main.async {
                        self.dismiss(animated: true, completion: nil)
                    }
                case .failure(let error):
                    self.errorData = error
                    DispatchQueue.main.async {
                        self.performSegue(withIdentifier: "SignMessageError", sender: self)
                    }
                @unknown default:
                    break
                }
            }
        }
    }
}
